# Welcome to flaskmng

## What is flaskmng?

**flaskmng** is a tool that manages Flask project. It is designed in MVT architecture.

## Documentation
Documentation **flaskmng** is [flaskmng.readthedocs.io](https://flaskmng.readthedocs.io)